.. _pydl.pydlutils:

=================================
SDSS Utilities (`pydl.pydlutils`)
=================================

Introduction
++++++++++++

This is a placeholder for pydlutils documentation.


API
+++

.. automodapi:: pydl.pydlutils
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.bspline
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.cooling
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.coord
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.image
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.mangle
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.math
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.misc
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.sdss
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.spheregroup
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.trace
    :no-inheritance-diagram:

.. automodapi:: pydl.pydlutils.yanny
    :no-inheritance-diagram:
